xquery version "3.1";

(:~
 : This modules handles calling the right HTML file for each selected index.
 : It is called by index-overview.html.
 :
 : @author Michelle Weidling
 : @version 1.0
 :)

module namespace index="http://bdn-edition.de/ns/index";

declare namespace tei="http://www.tei-c.org/ns/1.0";
declare namespace xhtml="http://www.w3.org/1999/xhtml";
declare namespace html="http://www.w3.org/1999/html";
declare namespace xi="http://www.w3.org/2001/XInclude";
declare namespace templates="http://exist-db.org/xquery/templates";
declare namespace textgrid="http://textgrid.info/namespaces/metadata/core/2010";
declare namespace bdn="http://www.bdn-edition.de/ns/1.0";

import module namespace bdn-utils="http://bdn-edition.de/ns/utils" at "utils.xqm";
import module namespace config="https://sade.textgrid.de/ns/config" at "../config.xqm";
import module namespace console="http://exist-db.org/xquery/console";
import module namespace functx="http://www.functx.com";

(:~
 : The main entry point of the module.
 :
 : TODO: implement the missing index views
 :)
declare
  %templates:wrap
  function index:main($node as node(), $model as map(*))
{
  let $file := request:get-parameter("file", "")
  let $author := substring-before($file, "-")
  let $mode :=  request:get-parameter("mode", "")
  let $type :=  request:get-parameter("type", "")
  return
    switch($mode)
      case "list" return
        index:display-list($author, $type)

      case "bubble" return ()

      case "bar" return ()

      default return
        index:display-overview()
};

(:~
 : Displays an overview of all available index views.
 :)
declare
  %templates:wrap
  function index:display-overview() as element(div)*
{
  let $file := request:get-parameter("file", "")
  let $type := request:get-parameter("type", "bible")
  let $url := "index-overview.html?file=" || $file || "&amp;type=" || $type

  return
    (
      <div class="row" style="margin-top: 10%">
        <div class="col-sm-2 offset-sm-1" />
        <div class="col-sm-4 index-list">
          <a class="index-link" href="{$url || "&amp;mode=list"}">
            <div class="index-wrapper">
              <i class="fas fa-list-ul"></i> <br />
              Übersicht in Listenform
            </div>
          </a>
        </div>
        <div class="col-sm-4 index-bubble index-disabled">
            <div class="index-wrapper">
              <i class="fas fa-chart-pie"></i> <br />
              Übersicht zu Häufigkeiten
            </div>
        </div>
        <div class="col-sm-2 offset-sm-1" />
      </div>,
      <div class="row" style="margin-top: 5%">
        <div class="col-sm-2 offset-sm-1" />
        <div class="col-sm-4 index-bar index-disabled">
            <div class="index-wrapper index-disabled">
              <i class="fas fa-chart-bar index-disabled"></i> <br />
              Verteilung im Werk
            </div>
        </div>
        <div class="col-sm-4">
        </div>
        <div class="col-sm-2 offset-sm-1" />
      </div>,
      <div class="row" style="margin-top: 5%">
        <div class="col-sm-2 offset-sm-1" />
        <div class="col-sm-8">
          <div class="alert alert-danger" role="alert">
              Bitte beachten Sie, dass derzeit nur die <strong>Übersicht in Listenform</strong> der Register zur Verfügung steht.
          </div>
        </div>
        <div class="col-sm-2 offset-sm-1" />
      </div>
    )
};

(:~
 : Displays the list view of an index.
 :)
declare
  %templates:wrap
  function index:display-list($author as xs:string, $index-type as xs:string)
  as element(div)* {
    let $file := doc($config:indices || $author || "-" || $index-type || ".html")
    return
      $file/*
};

(:~
 : Displays an overview of the available index types, e.g. Bible index.
 : This function is called by index-selection.html.
 :
 : TODO: index types that don't occur in a work shouldn't be displayed
 :)
declare
%templates:wrap
function index:selection($node as node(), $model as map(*)) as element(div)* {
  let $author := request:get-parameter("author", "noesselt")
  let $url := "index-overview.html?file=" || $author || "-full&amp;type="

  return
    (<div class="row" style="margin-top: 10%">
      <div class="col-sm-2 offset-sm-1" />
      <div class="col-sm-4">
        <a class="index-link" href="{$url || "bible-index"}">
          <div class="index-wrapper">
            <i class="fas fa-bible"></i> <br />
            Bibelstellenregister
          </div>
        </a>
      </div>
      <div class="col-sm-4">
        <a class="index-link" href="{$url || "persons-index"}">
          <div class="index-wrapper">
            <i class="fas fa-users"></i> <br />
            Personenregister
          </div>
        </a>
      </div>
      <div class="col-sm-2 offset-sm-1" />
    </div>,
    <div class="row" style="margin-top: 5%">
      <div class="col-sm-2 offset-sm-1" />
      <div class="col-sm-4">
        <a class="index-link" href="{$url || "subjects-index"}">
          <div class="index-wrapper">
            <i class="fas fa-sort-alpha-down"></i> <br />
            Sachregister
          </div>
        </a>
      </div>
      <div class="col-sm-4">
        <a class="index-link" href="{$url || "classics-index"}">
          <div class="index-wrapper">
            <i class="fas fa-university"></i> <br />
            Register antiker Autoren
          </div>
        </a>
      </div>
      <div class="col-sm-2 offset-sm-1" />
    </div>)
};
